==> icedtea-web_1.2.orig.tar.gz: icedtea-web-1.2/tests/jnlp_tests/simple/ReadProperties/testcases/ReadPropertiesTest.java <==
/* ReadPropertiesTest.java
Copyright (C) 2011 Red Hat, Inc.

This file is part of IcedTea.

IcedTea is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License as published by
the Free Software Foundation, version 2.

IcedTea is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with IcedTea; see the file COPYING.  If not, write to
the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version.
 */


import net.sourceforge.jnlp.ServerAccess;
import org.junit.Assert;
import org.junit.Test;

public class ReadPropertiesTest {

    private static ServerAccess server = new ServerAccess();

 
    @Test
    public void ReadPropertiesLunch1() throws Exception {
        System.out.println("connecting ReadProperties1 request");
        System.err.println("connecting ReadProperties1 request");
        ServerAccess.ProcessResult pr=server.executeJavawsHeadless(null,"/ReadProperties1.jnlp");
        System.out.println(pr.stdout);
        System.err.println(pr.stderr);
        String s="java.security.AccessControlException: access denied (java.util.PropertyPermission user.name read)";
        Assert.assertTrue("stderr should contains "+s+" but didn't",pr.stderr.contains(s));
        String cc="ClassNotFoundException";
        Assert.assertFalse("stderr should NOT contains `"+cc+"`, but did",pr.stderr.contains(cc));
        Assert.assertFalse("stdout length should be <=2, but was "+pr.stdout.length(),pr.stdout.length()>2);
        Assert.assertFalse("ReadPropertiesLunch1 should not be terminated, but was",pr.wasTerminated);
        Assert.assertEquals((Integer)0, pr.returnValue);
    }

 @Test
    public void ReadPropertiesLunch2() throws Exception {
        System.out.println("connecting ReadProperties2 request");
        System.err.println("connecting ReadProperties2 request");
        ServerAccess.ProcessResult pr=server.executeJavawsHeadless(null,"/ReadProperties2.jnlp");
        System.out.println(pr.stdout);
        System.err.println(pr.stderr);
        String s="java.security.AccessControlException: access denied (java.util.PropertyPermission user.home read)";
        Assert.assertTrue("stderr should contains "+s+" but didn't",pr.stderr.contains(s));
        String cc="ClassNotFoundException";
        Assert.assertFalse("stderr should NOT contains `"+cc+"`, but did",pr.stderr.contains(cc));
        Assert.assertFalse("stdout length should be <=2, but was "+pr.stdout.length(),pr.stdout.length()>2);
        Assert.assertFalse("ReadPropertiesLunch2 should not be terminated, but was",pr.wasTerminated);
        Assert.assertEquals((Integer)0, pr.returnValue);
    }
  }

==> icedtea-web_1.2.3.orig.tar.gz: icedtea-web-1.2.3/tests/jnlp_tests/simple/ReadProperties/testcases/ReadPropertiesTest.java <==
/* ReadPropertiesTest.java
Copyright (C) 2011 Red Hat, Inc.

This file is part of IcedTea.

IcedTea is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License as published by
the Free Software Foundation, version 2.

IcedTea is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with IcedTea; see the file COPYING.  If not, write to
the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version.
 */


import net.sourceforge.jnlp.ServerAccess;
import org.junit.Assert;
import org.junit.Test;

public class ReadPropertiesTest {

    private static ServerAccess server = new ServerAccess();

 
    @Test
    public void ReadPropertiesLunch1() throws Exception {
        System.out.println("connecting ReadProperties1 request");
        System.err.println("connecting ReadProperties1 request");
        ServerAccess.ProcessResult pr=server.executeJavawsHeadless(null,"/ReadProperties1.jnlp");
        System.out.println(pr.stdout);
        System.err.println(pr.stderr);
        String s = "(?s).*java.security.AccessControlException.{0,5}access denied.{0,5}java.util.PropertyPermission.{0,5}" + "user.name.{0,5}read" + ".*";
        Assert.assertTrue("stderr should match "+s+" but didn't",pr.stderr.matches(s));
        String cc="ClassNotFoundException";
        Assert.assertFalse("stderr should NOT contains `"+cc+"`, but did",pr.stderr.contains(cc));
        Assert.assertFalse("stdout length should be <=2, but was "+pr.stdout.length(),pr.stdout.length()>2);
        Assert.assertFalse("ReadPropertiesLunch1 should not be terminated, but was",pr.wasTerminated);
        Assert.assertEquals((Integer)0, pr.returnValue);
    }

    @Test
    public void ReadPropertiesLunch2() throws Exception {
        System.out.println("connecting ReadProperties2 request");
        System.err.println("connecting ReadProperties2 request");
        ServerAccess.ProcessResult pr=server.executeJavawsHeadless(null,"/ReadProperties2.jnlp");
        System.out.println(pr.stdout);
        System.err.println(pr.stderr);
        String s = "(?s).*java.security.AccessControlException.{0,5}access denied.{0,5}java.util.PropertyPermission.{0,5}" + "user.home.{0,5}read" + ".*";
        Assert.assertTrue("stderr should match "+s+" but didn't",pr.stderr.matches(s));
        String cc="ClassNotFoundException";
        Assert.assertFalse("stderr should NOT contains `"+cc+"`, but did",pr.stderr.contains(cc));
        Assert.assertFalse("stdout length should be <=2, but was "+pr.stdout.length(),pr.stdout.length()>2);
        Assert.assertFalse("ReadPropertiesLunch2 should not be terminated, but was",pr.wasTerminated);
        Assert.assertEquals((Integer)0, pr.returnValue);
    }
  }
